@@ -134,47 +134,15 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
         }
         // line 55
         yield "            </script>
-            <script>
-                (function() {
-
-                    const BRAND = 'Cause Buzz';
-
-                    function updateTitle() {
-
-                        let title = document.title || '';
-
-                        // Remove trailing \"| Mautic\"
-                        title = title.replace(/\\|\\s*Mautic\$/i, '').trim();
-
-                        // Remove duplicate brand
-                        title = title.replace(new RegExp('\\\\|\\\\s*' + BRAND + '\$', 'i'), '').trim();
-
-                        // If empty or just \"Mautic\"
-                        if (!title || title === 'Mautic') {
-                            document.title = BRAND;
-                            return;
-                        }
-
-                        document.title = title + ' | ' + BRAND;
-                    }
-
-                    // Initial load
-                    window.addEventListener('load', updateTitle);
-
-                    // Mautic SPA navigation event (official)
-                    document.addEventListener('mautic:page:load', updateTitle);
-
-                })();
-            </script>
 
             ";
-        // line 89
+        // line 57
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 90
+        // line 58
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 93
+        // line 61
         yield "
         </section>
     </body>
@@ -220,7 +188,7 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
      */
     public function getDebugInfo(): array
     {
-        return array (  195 => 36,  188 => 35,  178 => 93,  176 => 90,  172 => 89,  136 => 55,  122 => 43,  120 => 42,  114 => 38,  112 => 35,  102 => 28,  98 => 27,  88 => 20,  81 => 16,  75 => 13,  71 => 12,  67 => 11,  63 => 10,  59 => 9,  55 => 8,  50 => 6,  43 => 1,);
+        return array (  163 => 36,  156 => 35,  146 => 61,  144 => 58,  140 => 57,  136 => 55,  122 => 43,  120 => 42,  114 => 38,  112 => 35,  102 => 28,  98 => 27,  88 => 20,  81 => 16,  75 => 13,  71 => 12,  67 => 11,  63 => 10,  59 => 9,  55 => 8,  50 => 6,  43 => 1,);
     }
 
     public function getSourceContext(): Source
